summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJakob Normark <jakobnormark@gmail.com>2014-11-06 18:56:20 +0100
committerJakob Normark <jakobnormark@gmail.com>2014-11-06 18:56:20 +0100
commit413d634d27d3de0a9509dd7d9ff44d5b62f791b4 (patch)
treee713855278b12a83be68b71a69e54e0c5a325927
parentdfb7f592f9f6539901942b28d8f8def0ed393e75 (diff)
downloadpylint-413d634d27d3de0a9509dd7d9ff44d5b62f791b4.tar.gz
Fixed "standart" typos
-rw-r--r--doc/run.rst2
-rwxr-xr-xepylint.py14
2 files changed, 8 insertions, 8 deletions
diff --git a/doc/run.rst b/doc/run.rst
index f8a65e2..9b2b218 100644
--- a/doc/run.rst
+++ b/doc/run.rst
@@ -52,7 +52,7 @@ assuming Pylint options are stored in ``pylint_options`` string, as:
lint.py_run(pylint_options)
To silently run Pylint on a ``module_name.py`` module,
-and get its standart output and error:
+and get its standard output and error:
.. sourcecode:: python
diff --git a/epylint.py b/epylint.py
index b34ef63..4fd683e 100755
--- a/epylint.py
+++ b/epylint.py
@@ -114,18 +114,18 @@ def py_run(command_options='', return_std=False, stdout=None, stderr=None,
"""Run pylint from python
``command_options`` is a string containing ``pylint`` command line options;
``return_std`` (boolean) indicates return of created standart output
and error (see below);
``stdout`` and ``stderr`` are 'file-like' objects in which standart output
could be written.
Calling agent is responsible for stdout/err management (creation, close).
Default standart output and error are those from sys,
or standalone ones (``subprocess.PIPE``) are used
if they are not set and ``return_std``.
If ``return_std`` is set to ``True``, this function returns a 2-uple
containing standart output and error related to created process,
as follows: ``(stdout, stderr)``.
A trivial usage could be as follows:
@@ -134,14 +134,14 @@ def py_run(command_options='', return_std=False, stdout=None, stderr=None,
pylint 0.18.1,
...
- To silently run Pylint on a module, and get its standart output and error:
+ To silently run Pylint on a module, and get its standard output and error:
>>> (pylint_stdout, pylint_stderr) = py_run( 'module_name.py', True)
"""
# Create command line to call pylint
if os.name == 'nt':
script += '.bat'
command_line = script + ' ' + command_options
# Providing standart output and/or error if not set
if stdout is None:
if return_std:
stdout = PIPE
@@ -156,7 +156,7 @@ def py_run(command_options='', return_std=False, stdout=None, stderr=None,
p = Popen(command_line, shell=True, stdout=stdout, stderr=stderr,
env=_get_env(), universal_newlines=True)
p.wait()
# Return standart output and error
if return_std:
return (p.stdout, p.stderr)
@@ -114,18 +114,18 @@ def py_run(command_options='', return_std=False, stdout=None, stderr=None,
"""Run pylint from python
``command_options`` is a string containing ``pylint`` command line options;
- ``return_std`` (boolean) indicates return of created standart output
+ ``return_std`` (boolean) indicates return of created standard output
and error (see below);
@@ -114,18 +114,18 @@ def py_run(command_options='', return_std=False, stdout=None, stderr=None,
and error (see below);
- ``stdout`` and ``stderr`` are 'file-like' objects in which standart output
+ ``stdout`` and ``stderr`` are 'file-like' objects in which standard output
could be written.
Calling agent is responsible for stdout/err management (creation, close).
@@ -114,18 +114,18 @@ def py_run(command_options='', return_std=False, stdout=None, stderr=None,
could be written.
Calling agent is responsible for stdout/err management (creation, close).
- Default standart output and error are those from sys,
+ Default standard output and error are those from sys,
or standalone ones (``subprocess.PIPE``) are used
if they are not set and ``return_std``.
@@ -114,18 +114,18 @@ def py_run(command_options='', return_std=False, stdout=None, stderr=None,
if they are not set and ``return_std``.
If ``return_std`` is set to ``True``, this function returns a 2-uple
- containing standart output and error related to created process,
+ containing standard output and error related to created process,
as follows: ``(stdout, stderr)``.
A trivial usage could be as follows:
@@ -134,14 +134,14 @@ def py_run(command_options='', return_std=False, stdout=None, stderr=None,
script += '.bat'
command_line = script + ' ' + command_options
- # Providing standart output and/or error if not set
+ # Providing standard output and/or error if not set
if stdout is None:
if return_std:
@@ -156,7 +156,7 @@ def py_run(command_options='', return_std=False, stdout=None, stderr=None,
env=_get_env(), universal_newlines=True)
p.wait()
- # Return standart output and error
+ # Return standard output and error
if return_std:
return (p.stdout, p.stderr)